#! /bin/bash
source $FW4EX_LIB_DIR/basicLib.sh
source $FW4EX_LIB_DIR/moreLib.sh

CFLAGS='-std=c99 -pedantic -Wall -Werror'
CC=gcc
OFILE=min.o

# HACK, plutot que compile.sh sorte avec le code 51 et que l'on
# n'enchaine pas sur check.sh, on tourne toujours check.sh mais
# l'on regarde si min.o existe bien!                                FIXME
if [[ ! -r $OFILE ]]
then exit 
fi

# -1- ###################################################################
# le nombre d'epreuves a tester. Chaque test rapportera
# 1/$DATA_NUMBER point.
DATA_NUMBER=$( ls $FW4EX_EXERCISE_DIR/tests/main*.c | wc -l )

# -2- ###################################################################
# Comparaison
cat <<EOF
<p>
Je vais incorporer votre fonction dans $DATA_NUMBER fichiers
la mettant en oeuvre. Je testerai ainsi comment se comporte votre
fonction sur quelques données.
</p>
EOF

I=0
for main in $FW4EX_EXERCISE_DIR/tests/main*.c
do 
    # presentation de main.c
    I=$(( $I+1 ))
    cat <<EOF
<section rank='$I'>
<p> Voici le contenu du fichier $I mettant en oeuvre votre fonction:
<pre>
EOF
    fw4ex_transcode_carefully < $main
    cat <<EOF
</pre></p>

<p> Je compile ce fichier </p>
EOF

    # compilation
    if $CC $CFLAGS -o $TMPDIR/main $main $OFILE 2>$TMPDIR/err.s 
    then
        abort=false
        cat <<EOF
<p>La compilation a réussi.</p>
EOF
    else
        abort=true
        cat <<EOF
<p>La compilation s'est mal passée!</p>
EOF
    fi

    # affichage anomalies
    if [[ -s $TMPDIR/err.s ]]
    then
        cat <<EOF
<error>Attention: la compilation a produit, sur son flux d'erreur, les 
anomalies suivantes: <pre>
EOF
        fw4ex_transcode_carefully < $TMPDIR/err.s
        cat <<EOF
</pre></error>
EOF
    fi

    # fin prematuree si probleme
    if $abort
    then 
        cat <<EOF
<p> La compilation ayant échouée, j'abandonne donc ce test. </p>
EOF
        break
    fi

    # execution
    cat <<EOF
<p> Je demande à exécuter le programme obtenu.
EOF
    fw4ex_confine $TMPDIR/main 1>$TMPDIR/out.s 2>$TMPDIR/err.s
    CODE=$?
    if [[ "$CODE" = 0 ]]
    then
        cat <<EOF
Impeccable! Vous gagnez 
EOF
        fw4ex_win 1/$DATA_NUMBER
        echo " points</p>"
    else
        cat <<EOF
La réponse n'est pas ce que j'attendais! </p>
EOF
    fi
    fw4ex_generate_xml_comment "code:$CODE"

    # affichage stdout
    if [[ -s $TMPDIR/out.s ]]
    then
        echo "<warning>Votre programme a cependant aussi produit ceci:<pre>"
        fw4ex_transcode_carefully < $TMPDIR/out.s
        echo "</pre></warning>"
    fi
        
    # affichage anomalie
    if [[ -s $TMPDIR/err.s ]]
    then
        cat <<EOF
<error>Attention: l'exécution a produit, sur son flux d'erreur, les 
anomalies suivantes: <pre>
EOF
        fw4ex_transcode_carefully < $TMPDIR/err.s
        cat <<EOF
</pre></error>
EOF
    fi

    echo "</section>"

done

cat <<EOF
<p>
Fin de correction automatique.
</p>
EOF

# Local Variables: ##
# coding:utf-8 ##
# End: ##
# end of check.sh
