#! /bin/bash
source $FW4EX_LIB_DIR/basicLib.sh
source $FW4EX_LIB_DIR/moreLib.sh

CFLAGS='-std=c99 -pedantic -Wall -Werror'
CC=gcc
CFILE=min.c
OFILE=min.o

# -1- ###################################################################
# Verifier que le fichier 'min.c' existe!
if [[ ! -f "$CFILE" ]]
then
    cat <<EOF
<error> Je ne trouve pas de fichier $CFILE!</error>
EOF
    exit #51
fi

if [[ ! -r "$CFILE" ]]
then 
    chmod a+r "$CFILE"
fi

if [[ ! -s "$CFILE" ]]
then
    cat <<EOF
<error>Le fichier $CFILE est vide! </error>
EOF
    exit #51
fi

# On ajoute un LF a la fin du fichier pour eviter que gcc ne dise:
# min.c:6:13: error: no newline at end of file
echo >> $CFILE

cat <<EOF
<p> Voici le contenu de votre fichier $CFILE:
<pre>
EOF
fw4ex_transcode_carefully < $CFILE 
cat <<EOF
</pre></p>
EOF

# -2- ###################################################################
# On efface le min.o si d'aventure il etait present
if [ -f ${OFILE} ]
then rm -f ${OFILE} 2>/dev/null
fi

# -3- ###################################################################
# Compilation
command="${CC} ${CFLAGS} -c ${CFILE}"
cat <<EOF
<p> Je compile votre fichier avec la commande 
<code>$command</code>. </p>
EOF

if $command 2> $TMPDIR/err.s
then 
    exitcode=0
    cat <<EOF
<p> La compilation a réussi. </p>
EOF
else
    exitcode=$?
    cat <<EOF
<error>La compilation a eu des problèmes!
EOF
    if [[ -s $TMPDIR/err.s ]]
    then
        cat <<EOF
Attention! La compilation a produit les anomalies suivantes 
sur son flux d'erreur: <pre>
EOF
        fw4ex_transcode_carefully < $TMPDIR/err.s
        cat <<EOF
</pre>
EOF
        cat <<EOF
</error>
EOF
    fi
fi

exit #$exitcode

# Local Variables: ##
# coding:utf-8 ##
# End: ##
# end of compile.sh
